##
##  libpki.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2022 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         libpki
Summary:      Public-Key Infrastructure (PKI) Library
URL:          https://www.openca.org/projects/libpki/
Vendor:       Massimiliano Pala
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Cryptography
License:      GPL
Version:      0.9.0
Release:      20220909

#   package options
%option       with_ldap   no
%option       with_pgsql  no
%option       with_mysql  no

#   list of sources
Source0:      http://downloads.sourceforge.net/openca/libpki/libpki-%{version}.tar.gz
Patch0:       libpki.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  openssl, libxml
PreReq:       openssl, libxml
%if "%{with_ldap}" == "yes"
BuildPreReq:  openldap
PreReq:       openldap
%endif
%if "%{with_pgsql}" == "yes"
BuildPreReq:  postgresql
PreReq:       postgresql
%endif
%if "%{with_mysql}" == "yes"
BuildPreReq:  mysql
PreReq:       mysql
%endif

%description
    The LibPKI Project is aimed to provide an easy-to-use PKI library
    for PKI enabled application development. The library provides
    the developer with all the needed functionalities to manage
    certificates, from generation to validation. The LibPKI Project
    enables developers with the possibility to implement complex
    cryptographic operations with a few simple function calls by
    implementing an high-level cryptographic API. The LibPKI Project
    is aimed to provide an easy-to-use PKI library for PKI enabled
    application development. The library provides the developer with all
    the needed functionalities to manage certificates, from generation
    to validation. The LibPKI Project enables developers with the
    possibility to implement complex cryptographic operations with a few
    simple function calls by implementing an high-level cryptographic
    API. The library constitutes the core of the OpenCA-NG Project,
    anyway we provide it as a separate package in order to encourage
    applications developers to use it in their packages.

%track
    prog libpki = {
        version   = %{version}
        url       = https://www.openca.org/projects/libpki/sources.shtml
        regex     = libpki-(__VER__)\.tar\.gz
    }

%prep
    %setup -q
    %patch -p0

%build
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags}" \
    LIBS="-lssl -lcrypto" \
    ./configure \
        --prefix=%{l_prefix} \
        --mandir=%{l_prefix}/man \
        --with-libdir=%{l_prefix}/lib \
        --enable-openssl \
        --with-openssl-prefix=%{l_prefix} \
        --enable-openssl-engine \
        --enable-ecdsa \
        --with-xml2-prefix=%{l_prefix} \
%if "%{with_ldap}" == "yes"
        --enable-ldap \
        --with-ldap-prefix=%{l_prefix} \
%else
        --disable-ldap \
%endif
%if "%{with_mysql}" == "yes"
        --enable-mysql \
        --with-mysql-prefix=%{l_prefix} \
%else
        --disable-mysql \
%endif
%if "%{with_pgsql}" == "yes"
        --enable-pg \
        --with-pg-prefix=%{l_prefix} \
%else
        --disable-pg \
%endif
        --disable-shared
    %{l_make} %{l_mflags -O}

%install
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/share/libpki
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/share/man
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

